==> StorageGRID-11.6.0.16-Sources-FTP.tar.gz: cassandra-reaper-2.0.3/src/server/src/test/java/io/cassandrareaper/service/TestRepairConfiguration.java <==
/*
 * Copyright 2017-2017 Spotify AB
 * Copyright 2017-2018 The Last Pickle Ltd
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.cassandrareaper.service;

import io.cassandrareaper.ReaperApplicationConfiguration;
import io.cassandrareaper.ReaperApplicationConfigurationBuilder;
import io.cassandrareaper.ReaperApplicationConfigurationBuilder.AutoSchedulingConfigurationBuilder;

import org.apache.cassandra.repair.RepairParallelism;

public final class TestRepairConfiguration {

  private TestRepairConfiguration() {}

  public static ReaperApplicationConfiguration defaultConfig() {
    return defaultConfigBuilder().build();
  }

  public static ReaperApplicationConfigurationBuilder defaultConfigBuilder() {
    return ReaperApplicationConfigurationBuilder.aReaperApplicationConfiguration()
        .withEnableCrossOrigin(true)
        .withHangingRepairTimeoutMins(30)
        .withRepairIntensity(0.9)
        .withRepairParallelism(RepairParallelism.DATACENTER_AWARE)
        .withRepairRunThreadCount(15)
        .withScheduleDaysBetween(1)
        .withSegmentCount(200)
        .withStorageType("memory")
        .withAutoScheduling(defaultAutoSchedulingConfigBuilder().build());
  }

  public static AutoSchedulingConfigurationBuilder defaultAutoSchedulingConfigBuilder() {
    return new AutoSchedulingConfigurationBuilder().thatIsDisabled();
  }
}

==> StorageGRID-12.0.0-Sources-FTP.tar.gz: cassandra-reaper-3.7.0/src/server/src/test/java/io/cassandrareaper/service/TestRepairConfiguration.java <==
/*
 * Copyright 2017-2017 Spotify AB
 * Copyright 2017-2018 The Last Pickle Ltd
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.cassandrareaper.service;

import io.cassandrareaper.ReaperApplicationConfiguration;
import io.cassandrareaper.ReaperApplicationConfigurationBuilder;
import io.cassandrareaper.ReaperApplicationConfigurationBuilder.AutoSchedulingConfigurationBuilder;

import org.apache.cassandra.repair.RepairParallelism;

public final class TestRepairConfiguration {

  private TestRepairConfiguration() {
  }

  public static ReaperApplicationConfiguration defaultConfig() {
    return defaultConfigBuilder().build();
  }

  public static ReaperApplicationConfigurationBuilder defaultConfigBuilder() {
    return ReaperApplicationConfigurationBuilder.aReaperApplicationConfiguration()
        .withEnableCrossOrigin(true)
        .withHangingRepairTimeoutMins(30)
        .withRepairIntensity(0.9)
        .withRepairParallelism(RepairParallelism.DATACENTER_AWARE)
        .withRepairRunThreadCount(15)
        .withScheduleDaysBetween(1)
        .withSegmentCount(200)
        .withStorageType("memory")
        .withAutoScheduling(defaultAutoSchedulingConfigBuilder().build());
  }

  public static AutoSchedulingConfigurationBuilder defaultAutoSchedulingConfigBuilder() {
    return new AutoSchedulingConfigurationBuilder().thatIsDisabled();
  }
}
